@@ -3,7 +3,7 @@
     Copyright 2021 Hwakyeom Kim(=just-do-halee)
 */
 
-/// this will convert any result type to floating Result.
+/// this will convert any result type to Master Result.
 ///```no_run
 /// resultcast!(handle.join().unwrap())?;
 ///```
@@ -11,9 +11,18 @@
 #[macro_export]
 macro_rules! resultcast {
     ($result:expr) => {
-        match $result {
-            Ok(o) => Ok(o),
-            Err(e) => errbang!(err::__;@chain "{:?} {}\n                    ⎺↴", e, stringify!($result)),
-        }
+        Result::Ok(errcast!($result))
+    };
+}
+
+/// this will convert any result type to Master ResultSend.
+///```no_run
+/// resultcastsend!(handle.join().unwrap())?;
+///```
+/// result type cast macro
+#[macro_export]
+macro_rules! resultcastsend {
+    ($result:expr) => {
+        ResultSend::Ok(errcast!($result))
     };
 }
